Package: GIGSEA
Type: Package
Title: Genotype Imputed Gene Set Enrichment Analysis
Version: 1.29.0
Author: Shijia Zhu
Maintainer: Shijia Zhu <shijia.zhu@mssm.edu>
Description: We presented the Genotype-imputed Gene Set Enrichment Analysis (GIGSEA), a novel method that uses GWAS-and-eQTL-imputed trait-associated differential gene expression to interrogate gene set enrichment for the trait-associated SNPs. By incorporating eQTL from large gene expression studies, e.g. GTEx, GIGSEA appropriately addresses such challenges for SNP enrichment as gene size, gene boundary, SNP distal regulation, and multiple-marker regulation. The weighted linear regression model, taking as weights both imputation accuracy and model completeness, was used to perform the enrichment test, properly adjusting the bias due to redundancy in different gene sets. The permutation test, furthermore, is used to evaluate the significance of enrichment, whose efficiency can be largely elevated by expressing the computational intensive part in terms of large matrix operation. We have shown the appropriate type I error rates for GIGSEA (<5%), and the preliminary results also demonstrate its good performance to uncover the real signal. 
License: LGPL-3
Encoding: UTF-8
LazyData: true
Depends: R (>= 3.5), Matrix, MASS, locfdr, stats, utils
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
RoxygenNote: 6.0.1
NeedsCompilation: no
biocViews:
        GeneSetEnrichment,SNP,VariantAnnotation,GeneExpression,GeneRegulation,Regression,DifferentialExpression
git_url: https://git.bioconductor.org/packages/GIGSEA
git_branch: devel
git_last_commit: 456186a
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-30
Packaged: 2025-10-30 21:23:31 UTC; biocbuild
